pystencils
==========

Welcome to the documentation of the pystencils code generation tool for stencil codes.
pystencils can help you to generate blazingly fast code for image processing, numerical simulations or any other task involving numpy arrays.


.. toctree::
   :maxdepth: 2

   sphinx/tutorials.rst
   sphinx/api.rst


.. image:: /img/pystencils_arch_block_diagram.svg
    :height: 450px
    :align: center


